From 4089ba01e0881c89a72332e13bc3a80b6bddec2a Mon Sep 17 00:00:00 2001
From: Jake Vanderwerf <get@jakevanderwerf.ca>
Date: Mon, 29 Jun 2026 22:15:55 +0000
Subject: [PATCH] =DashboardManager overhaul. A bit easier to modify the output of pages. Still have to get the account pages to work as expected, as well as verify the integrations and others are working - but registrar/content pages work as expected. Also fixed up the table generation in CRUD.js and CRUDSkeleton.php
---
cleanup.php | 56 ++++++++++++++++++++++++++++++++++++++++++++++++++++----
1 files changed, 52 insertions(+), 4 deletions(-)
diff --git a/cleanup.php b/cleanup.php
index 461c845..1fd7797 100644
--- a/cleanup.php
+++ b/cleanup.php
@@ -34,6 +34,7 @@
'wp-block-library',
'wp-block-library-theme',
'wp-block-styles',
+ 'block-style-variation-styles'
];
foreach ($global_styles as $style) {
@@ -56,9 +57,11 @@
}
wp_dequeue_script('wp-block-template-skip-link');
- // Remove WordPress 6.5+ script modules
- wp_dequeue_script_module('@wordpress/interactivity');
- wp_deregister_script_module('@wordpress/interactivity');
+ if (!is_plugin_active('woocommerce/woocommerce.php')) {
+ wp_dequeue_script_module('@wordpress/interactivity');
+ wp_deregister_script_module('@wordpress/interactivity');
+ }
+
wp_dequeue_script_module('@wordpress/block-library/navigation/view');
wp_deregister_script_module('@wordpress/block-library/navigation/view');
@@ -210,7 +213,7 @@
BASE . 'gallery'
];
//TODO: Dynamically use MetaManager to get any image or gallery fields
foreach ($meta_fields as $meta_key) {
$meta_value = get_post_meta($post_id, $meta_key, true);
@@ -263,3 +266,48 @@
return $clean_classes;
}
add_filter('body_class', 'jvbBodyClasses');
+
+
+add_action('admin_init', function () {
+ // Redirect any user trying to access comments page
+ global $pagenow;
+
+ if ($pagenow === 'edit-comments.php') {
+ wp_redirect(admin_url());
+ exit;
+ }
+
+ // Remove comments metabox from dashboard
+ remove_meta_box('dashboard_recent_comments', 'dashboard', 'normal');
+
+ // Disable support for comments and trackbacks in post types
+ foreach (get_post_types() as $post_type) {
+ if (post_type_supports($post_type, 'comments')) {
+ remove_post_type_support($post_type, 'comments');
+ remove_post_type_support($post_type, 'trackbacks');
+ }
+ }
+});
+
+// Close comments on the front-end
+add_filter('comments_open', '__return_false', 20, 2);
+add_filter('pings_open', '__return_false', 20, 2);
+
+// Hide existing comments
+add_filter('comments_array', '__return_empty_array', 10, 2);
+
+// Remove comments page in menu
+add_action('admin_menu', function () {
+ remove_menu_page('edit-comments.php');
+});
+
+// Remove comments links from admin bar
+add_action('init', function () {
+ if (is_admin_bar_showing()) {
+ remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
+ }
+});
+// Remove comments links from admin bar
+add_action('add_admin_bar_menus', function () {
+ remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
+});
@@ -210,7 +213,7 @@
BASE . 'gallery'
];
- //TODO: Dynamically use MetaManager to get any image or gallery fields
+ //TODO: Dynamically use Meta.php to get any image or gallery fields
foreach ($meta_fields as $meta_key) {
$meta_value = get_post_meta($post_id, $meta_key, true);
--
Gitblit v1.10.0